@@ -3,7 +3,7 @@
 // RcppCommon.h: Rcpp R/C++ interface class library -- common include and defines statements
 //
 // Copyright (C) 2008 - 2009 Dirk Eddelbuettel
-// Copyright (C) 2009 - 2011 Dirk Eddelbuettel and Romain Francois
+// Copyright (C) 2009 - 2012 Dirk Eddelbuettel and Romain Francois
 //
 // This file is part of Rcpp.
 //
@@ -86,10 +86,13 @@ namespace Rcpp{
     #if GCC_VERSION >= 40500
         #define IS_GCC_450_OR_LATER
     #endif
-    // g++ 4.6 no longer has exception_defines.h so need a flag for that
+    // g++ 4.6 switches from exception_defines.h to bits/exception_defines.h
     #if GCC_VERSION < 40600
         #define IS_EARLIER_THAN_GCC_460
     #endif
+    #if GCC_VERSION >= 40600
+        #define IS_GCC_460_OR_LATER
+    #endif
 #endif
 
 #ifdef __INTEL_COMPILER
@@ -326,4 +329,8 @@ RcppExport SEXP RcppXPtrExample_get_external_pointer(SEXP );
 #include <Rcpp/routines.h>
 #include <Rcpp/cache.h>
 
+// "Rcout" iostream class contributed by Jelmer Ypma
+#include <Rcpp/iostream/Rstreambuf.h>
+#include <Rcpp/iostream/Rostream.h>
+
 #endif
